@@ -306,7 +306,7 @@ static gboolean
 get_thumbnail_idle (gpointer data)
 {
 	GtkamList *list = GTKAM_LIST (data);
-	GetThumbnailData *d = data;
+	GetThumbnailData *d;
 	CameraFile *file;
 	GtkWidget *s;
 	GdkPixbuf *pixbuf;
@@ -347,7 +347,7 @@ get_thumbnail_idle (gpointer data)
 		
 		gtk_list_store_set (list->priv->store, d->iter,
 				PREVIEW_COLUMN, pixbuf, -1);
-		gdk_pixbuf_unref (pixbuf);
+		g_object_unref (G_OBJECT (pixbuf));
 	} 
 	
 	gp_file_unref (file);
@@ -362,6 +362,8 @@ get_thumbnail_idle (gpointer data)
 	gtk_tree_iter_free (d->iter);
 	list->priv->head = d->next;
 	g_free (d);
+	if (!list->priv->head)
+		list->priv->tail = NULL;
 
 	gtk_widget_destroy (s);
 	
@@ -726,28 +728,6 @@ action_exif (gpointer callback_data, guint callback_action, GtkWidget *widget)
 }
 #endif
 
-static void
-action_save (gpointer callback_data, guint callback_action, GtkWidget *widget)
-{
-	GtkWidget *s;
-	GtkamList *list = GTKAM_LIST (callback_data);
-	GtkamCamera *camera;
-	gchar *folder;
-	gchar *name;
-
-	camera = gtkam_list_get_camera_from_iter (list, &list->priv->iter);
-	folder = gtkam_list_get_folder_from_iter (list, &list->priv->iter);
-	name   = gtkam_list_get_name_from_iter   (list, &list->priv->iter);
-
-	s = gtkam_save_new (GTK_WINDOW (gtk_widget_get_toplevel(
-			GTK_WIDGET(list) )));
-	gtkam_save_add (GTKAM_SAVE (s), camera, folder, name);
-	g_free (folder);
-	g_free (name);
-	g_signal_emit (G_OBJECT (list), signals[NEW_DIALOG], 0, s);
-	g_object_unref (G_OBJECT (s));
-}
-
 static void
 on_file_deleted (GtkamDelete *delete, GtkamDeleteFileDeletedData *data,
 		 GtkamList *list)
@@ -978,7 +958,7 @@ gtkam_list_add_folder (GtkamList *list, GtkamCamera *camera,
 		 */
 		if (!gdk_pixbuf_get_has_alpha (pixbuf)) {
 			tmp = gdk_pixbuf_add_alpha (pixbuf, FALSE, 0, 0, 0);
-			gdk_pixbuf_unref (pixbuf);
+			g_object_unref (G_OBJECT (pixbuf));
 			pixbuf = tmp;
 		}
 
@@ -987,7 +967,7 @@ gtkam_list_add_folder (GtkamList *list, GtkamCamera *camera,
 			tmp = gdk_pixbuf_new_from_file (
 				IMAGE_DIR "/gtkam-audio.png");
 			gdk_pixbuf_add (pixbuf, 0, 0, tmp);
-			gdk_pixbuf_unref (tmp);
+			g_object_unref (G_OBJECT (tmp));
 		}
 
 		/* Check for read-only flag */
@@ -1001,7 +981,7 @@ gtkam_list_add_folder (GtkamList *list, GtkamCamera *camera,
 				gdk_pixbuf_get_width (pixbuf) - w,
 				gdk_pixbuf_get_height (pixbuf) - h,
 				tmp);
-			gdk_pixbuf_unref (tmp);
+			g_object_unref ( G_OBJECT(tmp));
 		}
 
 		/* Check for downloaded flag */
@@ -1012,7 +992,7 @@ gtkam_list_add_folder (GtkamList *list, GtkamCamera *camera,
 			w = gdk_pixbuf_get_width (tmp);
 			gdk_pixbuf_add (pixbuf,
 				gdk_pixbuf_get_width (pixbuf) - w, 0, tmp);
-			gdk_pixbuf_unref (tmp);
+			g_object_unref ( G_OBJECT(tmp));
 		}
 
 		gdk_pixbuf_render_pixmap_and_mask (pixbuf,
@@ -1328,8 +1308,8 @@ zoom_factor (GtkamList *list, GtkTreeIter *iter, Zoom zoom)
 		}
 		break;
 	}
-	gdk_pixbuf_unref (pixbuf);
-	gdk_pixbuf_unref (pixbuf_orig);
+	g_object_unref (G_OBJECT (pixbuf));
+	g_object_unref (G_OBJECT (pixbuf_orig));
 
 	gtk_tree_view_columns_autosize (GTK_TREE_VIEW (list));
 }
